@@ -1,18 +1,18 @@
-require 'ffi_yajl'
-require 'chef_zero/endpoints/rest_object_endpoint'
-require 'chef_zero/endpoints/data_bag_item_endpoint'
-require 'chef_zero/chef_data/data_normalizer'
+require "ffi_yajl"
+require "chef_zero/endpoints/rest_object_endpoint"
+require "chef_zero/endpoints/data_bag_item_endpoint"
+require "chef_zero/chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
     # /data/NAME/NAME
     class DataBagItemEndpoint < RestObjectEndpoint
       def initialize(server)
-        super(server, 'id')
+        super(server, "id")
       end
 
       def populate_defaults(request, response_json)
-        DataBagItemEndpoint::populate_defaults(request, response_json, request.rest_path[3], request.rest_path[4])
+        DataBagItemEndpoint.populate_defaults(request, response_json, request.rest_path[3], request.rest_path[4])
       end
 
       def self.populate_defaults(request, response_json, data_bag, data_bag_item)
