@@ -1,5 +1,5 @@
-require 'ffi_yajl'
-require 'chef_zero/endpoints/cookbooks_base'
+require "ffi_yajl"
+require "chef_zero/endpoints/cookbooks_base"
 
 module ChefZero
   module Endpoints
@@ -7,11 +7,11 @@ module ChefZero
     class EnvironmentCookbooksEndpoint < CookbooksBase
       def get(request)
         environment = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..3]), :create_additions => false)
-        constraints = environment['cookbook_versions'] || {}
-        if request.query_params['num_versions'] == 'all'
+        constraints = environment["cookbook_versions"] || {}
+        if request.query_params["num_versions"] == "all"
           num_versions = nil
-        elsif request.query_params['num_versions']
-          num_versions = request.query_params['num_versions'].to_i
+        elsif request.query_params["num_versions"]
+          num_versions = request.query_params["num_versions"].to_i
         else
           num_versions = 1
         end
