@@ -1,5 +1,5 @@
-require 'ffi_yajl'
-require 'chef_zero/endpoints/cookbooks_base'
+require "ffi_yajl"
+require "chef_zero/endpoints/cookbooks_base"
 
 module ChefZero
   module Endpoints
@@ -7,11 +7,11 @@ module ChefZero
     class EnvironmentRecipesEndpoint < CookbooksBase
       def get(request)
         environment = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..3]), :create_additions => false)
-        constraints = environment['cookbook_versions'] || {}
+        constraints = environment["cookbook_versions"] || {}
         result = []
         filter_cookbooks(all_cookbooks_list(request), constraints, 1) do |name, versions|
           if versions.size > 0
-            cookbook = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..1] + ['cookbooks', name, versions[0]]), :create_additions => false)
+            cookbook = FFI_Yajl::Parser.parse(get_data(request, request.rest_path[0..1] + ["cookbooks", name, versions[0]]), :create_additions => false)
             result += recipe_names(name, cookbook)
           end
         end
