@@ -1,5 +1,5 @@
-require 'ffi_yajl'
-require 'chef_zero/rest_base'
+require "ffi_yajl"
+require "chef_zero/rest_base"
 
 module ChefZero
   module Endpoints
@@ -13,15 +13,15 @@ module ChefZero
       def post(request)
         sandbox_checksums = []
 
-        needed_checksums = FFI_Yajl::Parser.parse(request.body, :create_additions => false)['checksums']
+        needed_checksums = FFI_Yajl::Parser.parse(request.body, :create_additions => false)["checksums"]
         result_checksums = {}
         needed_checksums.keys.each do |needed_checksum|
-          if list_data(request, request.rest_path[0..1] + ['file_store', 'checksums']).include?(needed_checksum)
+          if list_data(request, request.rest_path[0..1] + %w{file_store checksums}).include?(needed_checksum)
             result_checksums[needed_checksum] = { :needs_upload => false }
           else
             result_checksums[needed_checksum] = {
               :needs_upload => true,
-              :url => build_uri(request.base_uri, request.rest_path[0..1] + ['file_store', 'checksums', needed_checksum])
+              :url => build_uri(request.base_uri, request.rest_path[0..1] + ["file_store", "checksums", needed_checksum]),
             }
             sandbox_checksums << needed_checksum
           end
@@ -29,20 +29,20 @@ module ChefZero
 
         # There is an obvious race condition here.
         id = @next_id.to_s
-        @next_id+=1
+        @next_id += 1
 
-        time_str = Time.now.utc.strftime('%Y-%m-%dT%H:%M:%S%z')
+        time_str = Time.now.utc.strftime("%Y-%m-%dT%H:%M:%S%z")
         time_str = "#{time_str[0..21]}:#{time_str[22..23]}"
 
         create_data(request, request.rest_path, id, FFI_Yajl::Encoder.encode({
           :create_time => time_str,
-          :checksums => sandbox_checksums
+          :checksums => sandbox_checksums,
         }, :pretty => true))
 
         json_response(201, {
           :uri => build_uri(request.base_uri, request.rest_path + [id]),
           :checksums => result_checksums,
-          :sandbox_id => id
+          :sandbox_id => id,
         })
       end
     end
